cumulusci.tasks.metadata package
================================

Subpackages
-----------

.. toctree::

   cumulusci.tasks.metadata.tests

Submodules
----------


.. automodule:: cumulusci.tasks.metadata.ee_src
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metadata.managed_src
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metadata.modify
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metadata.package
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.metadata
   :members:
   :undoc-members:
   :show-inheritance:
